@@ -54,7 +54,6 @@ class Number {
 		void testInteger();
 		bool testErrors(int error_level = 1) const;
 		bool testFloatResult(bool allow_infinite_result = true, int error_level = 1, bool test_integer = true);
-		void setPrecisionAndApproximateFrom(const Number &o);
 
 		mpq_t r_value;
 		mpfr_t fu_value;
@@ -98,7 +97,7 @@ class Number {
 		void set(long int numerator, long int denominator = 1, long int exp_10 = 0, bool keep_precision = false, bool keep_imag = false);
 		void setPlusInfinity(bool keep_precision = false, bool keep_imag = false);
 		void setMinusInfinity(bool keep_precision = false, bool keep_imag = false);
-		void setFloat(double d_value);
+		void setFloat(long double d_value);
 		bool setInterval(const Number &nr_lower, const Number &nr_upper, bool keep_precision = false);
 
 		void setInternal(const mpz_t &mpz_value, bool keep_precision = false, bool keep_imag = false);
@@ -127,6 +126,8 @@ class Number {
 		void precisionToInterval();
 		bool intervalToPrecision(long int min_precision = 2);
 		void intervalToMidValue();
+		void splitInterval(unsigned int nr_of_parts, vector<Number> &v) const;
+		bool getCentralInteger(Number &nr_int, bool *b_multiple = NULL, vector<Number> *v = NULL) const;
 		bool mergeInterval(const Number &o, bool set_to_overlap = false);
 		void setUncertainty(const Number &o, bool force_interval = false);
 		Number uncertainty() const;
@@ -156,6 +157,8 @@ class Number {
  		*/
 		bool isFloatingPoint() const;
 		
+		void setPrecisionAndApproximateFrom(const Number &o);
+		
 		bool isInterval(bool ignore_imag = true) const;
 		bool imaginaryPartIsInterval() const;
 		
@@ -242,6 +245,14 @@ class Number {
 		
 		bool operator == (const Number &o) const;
 		bool operator != (const Number &o) const;
+		bool operator < (const Number &o) const;
+		bool operator <= (const Number &o) const;
+		bool operator > (const Number &o) const;
+		bool operator >= (const Number &o) const;
+		bool operator < (long int i) const;
+		bool operator <= (long int i) const;
+		bool operator > (long int i) const;
+		bool operator >= (long int i) const;
 		bool operator == (long int i) const;
 		bool operator != (long int i) const;
 		
@@ -249,6 +260,7 @@ class Number {
 		bool bitOr(const Number &o);
 		bool bitXor(const Number &o);
 		bool bitNot();
+		bool bitCmp(unsigned int bits);
 		bool bitEqv(const Number &o);
 		bool shiftLeft(const Number &o);
 		bool shiftRight(const Number &o);
@@ -284,7 +296,7 @@ class Number {
 		bool hasNegativeSign() const;
 		bool hasPositiveSign() const;
 		bool equalsZero() const;
-		bool equals(const Number &o, bool allow_interval = false) const;
+		bool equals(const Number &o, bool allow_interval = false, bool allow_infinite = false) const;
 		bool equals(long int i) const;
 		int equalsApproximately(const Number &o, int prec) const;
 		ComparisonResult compare(const Number &o, bool ignore_imag = false) const;
@@ -301,8 +313,6 @@ class Number {
 		bool isLessThan(long int i) const;
 		bool isGreaterThanOrEqualTo(long int i) const;
 		bool isLessThanOrEqualTo(long int i) const;
-		bool absIsGreaterThan(const Number &o) const;
-		bool absIsLessThan(const Number &o) const;
 		bool isEven() const;
 		bool numeratorIsGreaterThan(long int i) const;
 		bool numeratorIsLessThan(long int i) const;
@@ -402,7 +412,7 @@ class Number {
 		void setNegative(bool is_negative);
 		bool abs();
 		bool signum();
-		bool round(const Number &o);
+		bool round(const Number &o, bool halfway_to_even = true);
 		bool floor(const Number &o);
 		bool ceil(const Number &o);
 		bool trunc(const Number &o);
@@ -410,7 +420,7 @@ class Number {
 		bool isIntegerDivisible(const Number &o) const;
 		bool isqrt();
 		bool isPerfectSquare() const;
-		bool round();
+		bool round(bool halfway_to_even = true);
 		bool floor();
 		bool ceil();
 		bool trunc();	
